<?php
/**
 * Moun10 Pro: Color Patterns
 *
 * @package WordPress
 * @subpackage Moun10 Pro
 * @since 1.0
 */

/**
 * Generate the CSS for the current custom color scheme.
 */
function moun10_pro_custom_colors_css() {
  	$options= moun10_pro_get_theme_options();

	$color_value = $options['colorscheme_hue'];
	
	$css = '
	/*--------------------------------------------------------------
	# Background Color
	--------------------------------------------------------------*/
	.featured-content-wrapper .btn,
	.section-subtitle:after,
	.btn:hover, 
	.btn:focus,
	.slick-dots li.slick-active button,
	.jetpack_subscription_widget button[type="submit"],
	.pagination .page-numbers, 
	.pagination .page-numbers.dots:hover, 
	.pagination .page-numbers.dots:focus, 
	.pagination .page-numbers.prev, 
	.pagination .page-numbers.next,
	.reply a:hover, 
	.reply a:focus,
	input[type="submit"]:hover, 
	input[type="submit"]:focus,
	form.search-form button.search-submit {
	    background-color: ' . esc_attr( $color_value ) . ';
	}

	/*--------------------------------------------------------------
	# Text Color
	--------------------------------------------------------------*/
	.site-title a:hover,
	.main-navigation ul#primary-menu li.current-menu-item > a, 
	.main-navigation ul#primary-menu li:hover > a, 
	.main-navigation ul#primary-menu li:focus > a,
	.main-navigation a:hover, 
	.main-navigation ul.nav-menu > li > a:hover,
	.featured-content-wrapper .entry-title a:hover, 
	.featured-content-wrapper .entry-title a:focus,
	.section-subtitle,
	#our-services .entry-title a:hover,
	.more-link,
	.btn,
	.destination-slider .entry-title a:hover, 
	.destination-slider .entry-title a:focus,
	.entry-meta a:hover time,
	.entry-meta a,
	.blog-post-wrapper .entry-title a:hover, 
	span.byline a:hover, 
	.blog-widget ul li h3 a:hover,
	.position,
	#colophon .widget-title, 
	#colophon .widgettitle,
	#colophon a:hover, 
	#colophon a:focus,
	#colophon .site-info a,
	.testimonial-slider .entry-title a:hover, 
	.testimonial-slider .entry-title a:focus,
	#secondary .cat-links a, 
	#secondary a:hover, 
	#secondary a:focus,
	#secondary .widget-title, 
	#secondary .widgettitle,
	.single-wrapper .entry-meta span a:hover, 
	.single-wrapper .entry-meta span a:focus, 
	.single-wrapper .cat-links a, 
	.single-wrapper .entry-meta span.byline a.fn:hover, 
	.single-wrapper .entry-meta span.byline a.fn:focus,
	.navigation.post-navigation a:hover, 
	.navigation.posts-navigation a:hover, 
	.navigation.post-navigation a:focus, 
	.navigation.posts-navigation a:focus,
	.comment-meta .url:hover, 
	.comment-meta .url:focus,
	.comment-metadata a:hover time, 
	.comment-metadata a:focus time,
	p.logged-in-as a,
	.lite-version #secondary a:hover,
	.lite-version #secondary a:focus,
	.lite-version .blog-post-wrapper .entry-title a:hover,
	.lite-version .blog-post-wrapper .entry-title a:focus,
	.lite-version .blog-widget ul li h3 a:hover,
	.lite-version .blog-widget ul li h3 a:focus,
	.lite-version .navigation.post-navigation a:hover, 
	.lite-version .navigation.posts-navigation a:hover,
	.lite-version .navigation.post-navigation a:focus, 
	.lite-version .navigation.posts-navigation a:focus,
	.lite-version #our-services .entry-title a:hover,
	.lite-version #our-services .entry-title a:focus,
	.lite-version span.byline a:hover,
	.lite-version span.byline a:focus,
	.lite-version .testimonial-slider .entry-title a:hover,
	.lite-version .testimonial-slider .entry-title a:focus {
		color: ' . esc_attr( $color_value ) . ';
	}

	.main-navigation ul#primary-menu li:hover > svg, 
	.main-navigation ul#primary-menu li:focus > svg, 
	.main-navigation li.menu-item-has-children:hover > a > svg, 
	.main-navigation li.menu-item-has-children > a:hover > svg, 
	.main-navigation li.menu-item-has-children > a:focus > svg, 
	.main-navigation ul#primary-menu > li.current-menu-item > a > svg,
	.navigation.post-navigation a:hover svg, 
	.navigation.posts-navigation a:hover svg, 
	.navigation.post-navigation a:focus svg, 
	.navigation.posts-navigation a:focus svg {
		fill: ' . esc_attr( $color_value ) . ';
	}

	/*--------------------------------------------------------------
	# Border Color
	--------------------------------------------------------------*/

	.featured-content-wrapper .btn,
	.more-link,
	.btn,
	.testimonial-slider .slick-slide.slick-current.slick-active,
	.slick-dots li button,
	.pagination .page-numbers, 
	.pagination .page-numbers.dots:hover, 
	.pagination .page-numbers.dots:focus, 
	.pagination .page-numbers.prev, 
	.pagination .page-numbers.next {
		border-color: ' . esc_attr( $color_value ) . ';
	}

	/*--------------------------------------------------------------
	# Responsive Color
	--------------------------------------------------------------*/
	@media screen and (min-width: 1024px) {
		.main-navigation ul#primary-menu ul li.current-menu-item > a, 
		.main-navigation ul#primary-menu ul li:hover > a,
		.main-navigation ul#primary-menu ul li:focus > a {
			color: ' . esc_attr( $color_value ) . ';
		}
	}


	/*--------------------------------------------------------------
	# Preloader
	--------------------------------------------------------------*/

	@keyframes preloader {
	    0% {height:5px;transform:translateY(0px);background: ' . esc_attr( $color_value ) . ';}
	    25% {height:30px;transform:translateY(15px);background: ' . esc_attr( $color_value ) . ';}
	    50% {height:5px;transform:translateY(0px);background: ' . esc_attr( $color_value ) . ';}
	    100% {height:5px;transform:translateY(0px);background: ' . esc_attr( $color_value ) . ';}
	}';

	/**
	 * Filters Moun10 Pro custom colors CSS.
	 *
	 * @since Moun10 Pro 1.0.0
	 *
	 * @param string $css        Base theme colors CSS.
	 */
	return apply_filters( 'moun10_pro_custom_colors_css', $css );
}
