<?php
/**
 * Counter Section options
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */

// Add Counter section
$wp_customize->add_section( 'moun10_pro_counter_section', array(
	'title'             => esc_html__( 'Counters','moun10-pro' ),
	'description'       => esc_html__( 'Counters Section options.', 'moun10-pro' ),
	'panel'             => 'moun10_pro_front_page_panel',
) );

// Counter content enable control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[counter_section_enable]', array(
	'default'			=> 	$options['counter_section_enable'],
	'sanitize_callback' => 'moun10_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Moun10_Pro_Switch_Control( $wp_customize, 'moun10_pro_theme_options[counter_section_enable]', array(
	'label'             => esc_html__( 'Counter Section Enable', 'moun10-pro' ),
	'section'           => 'moun10_pro_counter_section',
	'on_off_label' 		=> moun10_pro_switch_options(),
) ) );


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[counter_section_enable]', array(
		'selector'            => '#counter-section .tooltiptext',
		'settings'            => 'moun10_pro_theme_options[counter_section_enable]',
    ) );
}

$wp_customize->add_setting( 'moun10_pro_theme_options[counter_image]', array(
	'sanitize_callback' => 'moun10_pro_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'moun10_pro_theme_options[counter_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'moun10-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'moun10-pro' ), 1350, 385 ),
		'section'     		=> 'moun10_pro_counter_section',
		'active_callback'	=> 'moun10_pro_is_counter_section_enable',
) ) );

// counter number control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[counter_count]', array(
	'default'          	=> $options['counter_count'],
	'sanitize_callback' => 'moun10_pro_sanitize_number_range',
	'validate_callback' => 'moun10_pro_validate_counter_count',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[counter_count]', array(
	'label'             => esc_html__( 'Number of Counters', 'moun10-pro' ),
	'description'       => esc_html__( 'Note: Min 4 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'moun10-pro' ),
	'section'           => 'moun10_pro_counter_section',
	'active_callback'   => 'moun10_pro_is_counter_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 4,
		'max'	=> 8,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['counter_count']; $i++ ) :

	if($options['home_layout'] != 'default-design') {

		// counter note control and setting
		$wp_customize->add_setting( 'moun10_pro_theme_options[counter_content_icon_' . $i . ']', array(
			'sanitize_callback' => 'sanitize_text_field',
		) );
	
		$wp_customize->add_control( new Moun10_Pro_Icon_Picker( $wp_customize, 'moun10_pro_theme_options[counter_content_icon_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select Icon %d', 'moun10-pro' ), $i ),
			'section'           => 'moun10_pro_counter_section',
			'active_callback'	=> 'moun10_pro_is_counter_section_enable',
		) ) );
	}

	// counter title setting and control
	$wp_customize->add_setting( 'moun10_pro_theme_options[counter_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'moun10_pro_theme_options[counter_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Counter Title %d', 'moun10-pro' ), $i ),
		'section'        	=> 'moun10_pro_counter_section',
		'active_callback' 	=> 'moun10_pro_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter title setting and control
	$wp_customize->add_setting( 'moun10_pro_theme_options[counter_number_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'moun10_pro_theme_options[counter_number_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Counter Count %d', 'moun10-pro' ), $i ),
		'section'        	=> 'moun10_pro_counter_section',
		'active_callback' 	=> 'moun10_pro_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter hr setting and control
	$wp_customize->add_setting( 'moun10_pro_theme_options[counter_hr_'. $i .']', array(
		'sanitize_callback' => 'moun10_pro_sanitize_html'
	) );

	$wp_customize->add_control( new Moun10_Pro_Customize_Horizontal_Line( $wp_customize, 'moun10_pro_theme_options[counter_hr_'. $i .']',
		array(
			'section'         => 'moun10_pro_counter_section',
			'active_callback' => 'moun10_pro_is_counter_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;



