<?php
/**
 * Course Section options
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */

// Add Course section
$wp_customize->add_section( 'moun10_pro_course_section', array(
	'title'             => esc_html__( 'Course','moun10-pro' ),
	'description'       => esc_html__( 'Course Section options.', 'moun10-pro' ),
	'panel'             => 'moun10_pro_front_page_panel',
) );

// Course content enable control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[course_section_enable]', array(
	'default'			=> 	$options['course_section_enable'],
	'sanitize_callback' => 'moun10_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Moun10_Pro_Switch_Control( $wp_customize, 'moun10_pro_theme_options[course_section_enable]', array(
	'label'             => esc_html__( 'Course Section Enable', 'moun10-pro' ),
	'section'           => 'moun10_pro_course_section',
	'on_off_label' 		=> moun10_pro_switch_options(),
) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[course_section_enable]', array(
		'selector'            => '#courses .tooltiptext',
		'settings'            => 'moun10_pro_theme_options[course_section_enable]',
    ) );
}

// course title setting and control
$wp_customize->add_setting( 'moun10_pro_theme_options[course_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['course_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[course_title]', array(
	'label'           	=> esc_html__( 'Title', 'moun10-pro' ),
	'section'        	=> 'moun10_pro_course_section',
	'active_callback' 	=> 'moun10_pro_is_course_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[course_title]', array(
		'selector'            => '#courses h2.business-section-title',
		'settings'            => 'moun10_pro_theme_options[course_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'moun10_pro_course_title_partial',
    ) );
}

// course description setting and control
$wp_customize->add_setting( 'moun10_pro_theme_options[course_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['course_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[course_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'moun10-pro' ),
	'section'        	=> 'moun10_pro_course_section',
	'active_callback' 	=> 'moun10_pro_is_course_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[course_sub_title]', array(
		'selector'            => '#courses p.business-section-subtitle',
		'settings'            => 'moun10_pro_theme_options[course_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'moun10_pro_course_sub_title_partial',
    ) );
}

// Slider number control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[course_count]', array(
	'default'          	=> $options['course_count'],
	'sanitize_callback' => 'moun10_pro_sanitize_number_range',
	'validate_callback' => 'moun10_pro_validate_course_count',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[course_count]', array(
	'label'             => esc_html__( 'Number of Featured', 'moun10-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'moun10-pro' ),
	'section'           => 'moun10_pro_course_section',
	'active_callback'   => 'moun10_pro_is_course_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Course content type control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[course_content_type]', array(
	'default'          	=> $options['course_content_type'],
	'sanitize_callback' => 'moun10_pro_sanitize_select',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[course_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'moun10-pro' ),
	'section'           => 'moun10_pro_course_section',
	'type'				=> 'select',
	'active_callback' 	=> 'moun10_pro_is_course_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'moun10-pro' ),
		'post' 		=> esc_html__( 'Post', 'moun10-pro' ),
		'category' 	=> esc_html__( 'Category', 'moun10-pro' ),
	),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'moun10_pro_theme_options[course_content_category]', array(
	'sanitize_callback' => 'moun10_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Moun10_Pro_Dropdown_Taxonomies_Control( $wp_customize,'moun10_pro_theme_options[course_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'moun10-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'moun10-pro' ),
	'section'           => 'moun10_pro_course_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'moun10_pro_is_course_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['course_count']; $i++ ) :
	// course pages drop down chooser control and setting
	$wp_customize->add_setting( 'moun10_pro_theme_options[course_content_page_' . $i . ']', array(
		'sanitize_callback' => 'moun10_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Moun10_Pro_Dropdown_Chooser( $wp_customize, 'moun10_pro_theme_options[course_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'moun10-pro' ), $i ),
		'section'           => 'moun10_pro_course_section',
		'choices'			=> moun10_pro_page_choices(),
		'active_callback'	=> 'moun10_pro_is_course_section_content_page_enable',
	) ) );

	// course posts drop down chooser control and setting
	$wp_customize->add_setting( 'moun10_pro_theme_options[course_content_post_' . $i . ']', array(
		'sanitize_callback' => 'moun10_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Moun10_Pro_Dropdown_Chooser( $wp_customize, 'moun10_pro_theme_options[course_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'moun10-pro' ), $i ),
		'section'           => 'moun10_pro_course_section',
		'choices'			=> moun10_pro_post_choices(),
		'active_callback'	=> 'moun10_pro_is_course_section_content_post_enable',
	) ) );

endfor;

