<?php
/**
 * Call To Action Section options
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */

// Add cta section
$wp_customize->add_section( 'moun10_pro_cta_section', array(
	'title'             => esc_html__( 'Call To Action','moun10-pro' ),
	'description'       => esc_html__( 'CTA Section options.', 'moun10-pro' ),
	'panel'             => 'moun10_pro_front_page_panel',

) );

// cta content enable control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[cta_section_enable]', array(
	'default'			=> 	$options['cta_section_enable'],
	'sanitize_callback' => 'moun10_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Moun10_Pro_Switch_Control( $wp_customize, 'moun10_pro_theme_options[cta_section_enable]', array(
	'label'             => esc_html__( 'CTA Section Enable', 'moun10-pro' ),
	'section'           => 'moun10_pro_cta_section',
	'on_off_label' 		=> moun10_pro_switch_options(),
) ) );


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[cta_section_enable]', array(
		'selector'            => '#call-to-action .tooltiptext',
		'settings'            => 'moun10_pro_theme_options[cta_section_enable]',
    ) );
}

// cta sub title control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[cta_sub_title]', array(
    'default'           => $options['cta_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'moun10_pro_theme_options[cta_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'moun10-pro' ),
	'section'        	=> 'moun10_pro_cta_section',
	'active_callback' 	=> 'moun10_pro_is_cta_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[cta_sub_title]', array(
		'selector'            => '#call-to-action .section-header span.section-subtitle',
		'settings'            => 'moun10_pro_theme_options[cta_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'moun10_pro_cta_sub_title_partial',
    ) );
}

// cta content type control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[cta_content_type]', array(
    'default'          	=> $options['cta_content_type'],
    'sanitize_callback' => 'moun10_pro_sanitize_select',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[cta_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'moun10-pro' ),
    'section'           => 'moun10_pro_cta_section',
    'type'				=> 'select',
    'active_callback' 	=> 'moun10_pro_is_cta_section_enable',
    'choices'			=> moun10_pro_cta_content_type(),
) );

$wp_customize->add_setting( 'moun10_pro_theme_options[cta_content_page]', array(
    'sanitize_callback' => 'moun10_pro_sanitize_page',
) );

$wp_customize->add_control( new Moun10_Pro_Dropdown_Chooser( $wp_customize, 'moun10_pro_theme_options[cta_content_page]', array(
    'label'             => esc_html__( 'Select Page', 'moun10-pro' ),
    'section'           => 'moun10_pro_cta_section',
    'choices'			=> moun10_pro_page_choices(),
    'active_callback'	=> 'moun10_pro_is_cta_section_content_page_enable',
) ) );

// cta posts drop down chooser control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[cta_content_post]', array(
    'sanitize_callback' => 'moun10_pro_sanitize_page',
) );

$wp_customize->add_control( new Moun10_Pro_Dropdown_Chooser( $wp_customize, 'moun10_pro_theme_options[cta_content_post]', array(
    'label'             => esc_html__( 'Select posts', 'moun10-pro' ),
    'section'           => 'moun10_pro_cta_section',
    'choices'			=> moun10_pro_post_choices(),
    'active_callback'	=> 'moun10_pro_is_cta_section_content_post_enable',
) ) );


// cta trips drop down chooser control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[cta_content_trip]', array(
	'sanitize_callback' => 'moun10_pro_sanitize_page',
) );

$wp_customize->add_control( new Moun10_Pro_Dropdown_Chooser( $wp_customize, 'moun10_pro_theme_options[cta_content_trip]', array(
	'label'             =>  esc_html__( 'Select Trip', 'moun10-pro'),
	'section'           => 'moun10_pro_cta_section',
	'choices'			=> moun10_pro_trip_choices(),
	'active_callback'	=> 'moun10_pro_is_cta_section_content_trip_enable',
) ) );


// cta read more setting and control
$wp_customize->add_setting( 'moun10_pro_theme_options[cta_read_more]', array(
	'default'			=> $options['cta_read_more'],
    'sanitize_callback' => 'sanitize_text_field',
    'transport'         =>'postMessage',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[cta_read_more]', array(
	'label'           	=> esc_html__( 'Read More Text', 'moun10-pro' ),
	'section'        	=> 'moun10_pro_cta_section',
	'active_callback' 	=> 'moun10_pro_is_cta_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[cta_read_more]', array(
		'selector'            => '#call-to-action .wrapper .read-more a.btn',
		'settings'            => 'moun10_pro_theme_options[cta_read_more]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'moun10_pro_cta_read_more_partial',
    ) );
}
