<?php
/**
 * Recommended Packages Section options
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */

// Add Recommended Packages section
$wp_customize->add_section( 'moun10_pro_recommended_package_section', array(
	'title'             => esc_html__( 'Recommended Packages','moun10-pro' ),
	'description'       => esc_html__( 'Recommended Packages Section options.', 'moun10-pro' ),
	'panel'             => 'moun10_pro_front_page_panel',

) );

// Recommended Packages content enable control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[recommended_package_section_enable]', array(
	'default'			=> 	$options['recommended_package_section_enable'],
	'sanitize_callback' => 'moun10_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Moun10_Pro_Switch_Control( $wp_customize, 'moun10_pro_theme_options[recommended_package_section_enable]', array(
	'label'             => esc_html__( 'Recommended Packages Section Enable', 'moun10-pro' ),
	'section'           => 'moun10_pro_recommended_package_section',
	'on_off_label' 		=> moun10_pro_switch_options(),
) ) );


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[recommended_package_section_enable]', array(
		'selector'            => '#recommended-packages .tooltiptext',
		'settings'            => 'moun10_pro_theme_options[recommended_package_section_enable]',
    ) );
}

// popular destination sub title setting and control
$wp_customize->add_setting( 'moun10_pro_theme_options[recommended_package_sub_title]', array(
	'default'			=> $options['recommended_package_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[recommended_package_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'moun10-pro' ),
	'section'        	=> 'moun10_pro_recommended_package_section',
	'active_callback' 	=> 'moun10_pro_is_recommended_package_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[recommended_package_sub_title]', array(
		'selector'            => '#recommended-packages .section-header p',
		'settings'            => 'moun10_pro_theme_options[recommended_package_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'moun10_pro_recommended_package_sub_title_partial',
    ) );
}

// popular destination title setting and control
$wp_customize->add_setting( 'moun10_pro_theme_options[recommended_package_title]', array(
	'default'			=> $options['recommended_package_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[recommended_package_title]', array(
	'label'           	=> esc_html__( 'Title', 'moun10-pro' ),
	'section'        	=> 'moun10_pro_recommended_package_section',
	'active_callback' 	=> 'moun10_pro_is_recommended_package_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[recommended_package_title]', array(
		'selector'            => '#recommended-packages div.section-header h2',
		'settings'            => 'moun10_pro_theme_options[recommended_package_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'moun10_pro_recommended_package_title_partial',
    ) );
}

//Recommended Packages post count number control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[recommended_package_count]', array(
	'default'          	=> $options['recommended_package_count'],
	'sanitize_callback' => 'moun10_pro_sanitize_number_range',
	'validate_callback' => 'moun10_pro_validate_recommended_package_count',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[recommended_package_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'moun10-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'moun10-pro' ),
	'section'           => 'moun10_pro_recommended_package_section',
	'active_callback'   => 'moun10_pro_is_recommended_package_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Recommended Packages content type control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[recommended_package_content_type]', array(
	'default'          	=> $options['recommended_package_content_type'],
	'sanitize_callback' => 'moun10_pro_sanitize_select',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[recommended_package_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'moun10-pro' ),
	'section'           => 'moun10_pro_recommended_package_section',
	'type'				=> 'select',
	'active_callback' 	=> 'moun10_pro_is_recommended_package_section_enable',
	'choices'			=> moun10_pro_recommended_package_content_type(),
) );

for ( $i=1; $i <= $options['recommended_package_count']; $i++ ) { 
	// Popular deatination pages drop down chooser control and setting
	$wp_customize->add_setting( 'moun10_pro_theme_options[recommended_package_content_page_' . $i . ']', array(
		'sanitize_callback' => 'moun10_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Moun10_Pro_Dropdown_Chooser( $wp_customize, 'moun10_pro_theme_options[recommended_package_content_page_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Page %d', 'moun10-pro' ), $i ),
		'section'           => 'moun10_pro_recommended_package_section',
		'choices'			=> moun10_pro_page_choices(),
		'active_callback'	=> 'moun10_pro_is_recommended_package_section_content_page_enable',
	) ) );

	// Popular deatination posts drop down chooser control and setting
	$wp_customize->add_setting( 'moun10_pro_theme_options[recommended_package_content_post_' . $i . ']', array(
		'sanitize_callback' => 'moun10_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Moun10_Pro_Dropdown_Chooser( $wp_customize, 'moun10_pro_theme_options[recommended_package_content_post_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select posts %d', 'moun10-pro' ), $i ),
		'section'           => 'moun10_pro_recommended_package_section',
		'choices'			=> moun10_pro_post_choices(),
		'active_callback'	=> 'moun10_pro_is_recommended_package_section_content_post_enable',
	) ) );

	// recommended_package trips drop down chooser control and setting
	$wp_customize->add_setting( 'moun10_pro_theme_options[recommended_package_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'moun10_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Moun10_Pro_Dropdown_Chooser( $wp_customize, 'moun10_pro_theme_options[recommended_package_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'moun10-pro' ), $i ),
		'section'           => 'moun10_pro_recommended_package_section',
		'choices'			=> moun10_pro_trip_choices(),
		'active_callback'	=> 'moun10_pro_is_recommended_package_section_content_trip_enable',
	) ) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'moun10_pro_theme_options[recommended_package_content_category]', array(
	'sanitize_callback' => 'moun10_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Moun10_Pro_Dropdown_Taxonomies_Control( $wp_customize,'moun10_pro_theme_options[recommended_package_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'moun10-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'moun10-pro' ),
	'section'           => 'moun10_pro_recommended_package_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'moun10_pro_is_recommended_package_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'moun10_pro_theme_options[recommended_package_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Moun10_Pro_Dropdown_Taxonomies_Control( $wp_customize,'moun10_pro_theme_options[recommended_package_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'moun10-pro' ),
	'section'           => 'moun10_pro_recommended_package_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'moun10_pro_is_recommended_package_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'moun10_pro_theme_options[recommended_package_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Moun10_Pro_Dropdown_Taxonomies_Control( $wp_customize,'moun10_pro_theme_options[recommended_package_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'moun10-pro' ),
	'section'           => 'moun10_pro_recommended_package_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'moun10_pro_is_recommended_package_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'moun10_pro_theme_options[recommended_package_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Moun10_Pro_Dropdown_Taxonomies_Control( $wp_customize,'moun10_pro_theme_options[recommended_package_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'moun10-pro' ),
	'section'           => 'moun10_pro_recommended_package_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'moun10_pro_is_recommended_package_section_content_destination_enable'
) ) );


// Popular deatination btn label setting and control
$wp_customize->add_setting( 'moun10_pro_theme_options[recommended_package_read_more_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recommended_package_read_more_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[recommended_package_read_more_btn_label]', array(
	'label'           	=> esc_html__( 'Read More Button Label', 'moun10-pro' ),
	'section'        	=> 'moun10_pro_recommended_package_section',
	'active_callback' 	=> 'moun10_pro_is_recommended_package_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[recommended_package_read_more_btn_label]', array(
		'selector'            => '#recommended-packages article .entry-container .more-link a',
		'settings'            => 'moun10_pro_theme_options[recommended_package_read_more_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'moun10_pro_recommended_package_read_more_btn_label_partial',
    ) );
}

// Popular deatination btn label setting and control
$wp_customize->add_setting( 'moun10_pro_theme_options[recommended_package_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recommended_package_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[recommended_package_btn_label]', array(
	'label'           	=> esc_html__( 'Recommended Packages Button Label', 'moun10-pro' ),
	'section'        	=> 'moun10_pro_recommended_package_section',
	'active_callback' 	=> 'moun10_pro_is_recommended_package_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[recommended_package_btn_label]', array(
		'selector'            => '#recommended-packages div.read-more a',
		'settings'            => 'moun10_pro_theme_options[recommended_package_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'moun10_pro_recommended_package_btn_label_partial',
    ) );
}

$wp_customize->add_setting( 'moun10_pro_theme_options[recommended_package_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[recommended_package_btn_url]', array(
	'label'           	=> esc_html__( 'Recommended Packages Button Url', 'moun10-pro' ),
	'section'        	=> 'moun10_pro_recommended_package_section',
	'active_callback' 	=> 'moun10_pro_is_recommended_package_section_enable',
	'type'				=> 'url',
) );