<?php
/**
 * Featured Package section
 *
 * This is the template for the content of popular Destination section
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */
if ( ! function_exists( 'moun10_pro_add_featured_package_section' ) ) :
	/**
	* Add popular Destination section
	*
	*@since Moun10 Pro 1.0.0
	*/
	function moun10_pro_add_featured_package_section() {
		$options = moun10_pro_get_theme_options();

			// Check if Destination is enabled on frontpage
			$featured_package_enable = apply_filters( 'moun10_pro_section_status', true, 'featured_package_section_enable' );

			if ( !in_array( $options['home_layout'], array( 'default-design' ) ) ) {
				$featured_package_enable = false;
			}
			
			if ( true !== $featured_package_enable ) {
				return false;
			}
			// Get Destination section details
			$section_details = array();
			$section_details = apply_filters( 'moun10_pro_filter_featured_package_section_details', $section_details );

			if ( empty( $section_details ) ) {
				return;
			}

			// Render Destination section now.
			moun10_pro_render_featured_package_section( $section_details );
		}
endif;

if ( ! function_exists( 'moun10_pro_get_featured_package_section_details' ) ) :
	/**
	* Featured Package section details.
	*
	* @since Moun10 Pro 1.0.0
	* @param array $input popular destination section details.
	*/
	function moun10_pro_get_featured_package_section_details( $input ) {
		$options = moun10_pro_get_theme_options();

		// Content type.
		$featured_package_content_type  = $options['featured_package_content_type'];
		$featured_package_count = ! empty( $options['featured_package_count'] ) ? $options['featured_package_count'] : 3;
		
		$content 		= array();
		switch ( $featured_package_content_type ) {
		
			case 'category':
                for ( $i = 1; $i <= $featured_package_count; $i++ ) {

                    if ( ! empty( $options['featured_package_content_category_' . $i] ) ){
						$page_post['id']      = $options['featured_package_content_category_' . $i];
                        $terms = get_term_by( 'id',  $page_post['id'], 'category' );

                        if ( ! empty( $terms ) && !is_wp_error($terms)) :
                            $page_post['title']   = $terms->name;
                            $page_post['url']     = get_category_link( $page_post['id'] );
							$page_post['count']   = $terms->count;
                            $page_post['image'] = ! empty( $options['featured_package_background_image_' . $i] ) ? $options['featured_package_background_image_' . $i] : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                        endif;
                    }
                    if ( ! empty(  $options['featured_package_content_category_' . $i] ) )
                        array_push( $content, $page_post );
                }                     
            break;

            case 'trip-types': // trip-types
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                for ( $i = 1; $i <= $featured_package_count; $i++ ) {
                    if ( ! empty( $options['featured_package_content_trip_types_' . $i] ) ){
                        $page_post['id']      = $options['featured_package_content_trip_types_' . $i];
						$cat_image = get_term_meta( $page_post['id'], 'wp_travel_trip_type_image_id', true);
						
                        $terms = get_term_by( 'id',  $page_post['id'], 'itinerary_types' );
						
                        if ( ! empty( $terms ) && !is_wp_error($terms)) :
                            $page_post['title']   = $terms->name;
                            $page_post['url']     = get_term_link( $page_post['id'], 'itinerary_types' );
                            $page_post['count']   = $terms->count;
							$page_post['image'] = ! empty( $cat_image ) ? wp_get_attachment_url( $cat_image ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                        endif;
                    }
                    if ( ! empty(  $options['featured_package_content_trip_types_' . $i] ) )
                        array_push( $content, $page_post );
                }
                     
            break;

            case 'destination': //Destination
                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                    
                for ( $i = 1; $i <= $featured_package_count; $i++ ) {
                    if ( ! empty( $options['featured_package_content_destination_' . $i] ) ){
                        $page_post['id']      = $options['featured_package_content_destination_' . $i];

						$cat_image = get_term_meta( $page_post['id'], 'wp_travel_trip_type_image_id', true);
						$terms = get_term_by( 'id',  $page_post['id'], 'travel_locations' );
						
						if ( ! empty( $terms ) && !is_wp_error($terms)) :
							$page_post['image'] = ! empty( $cat_image ) ? wp_get_attachment_url( $cat_image ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                            $page_post['title']   = $terms->name;
                            $page_post['url']     = get_term_link( $page_post['id'], 'travel_locations' );
                            $page_post['count']   = $terms->count;
                        endif;
                    }

                    if ( ! empty(  $options['featured_package_content_destination_' . $i] ) )
                        array_push( $content, $page_post );
                }   

            break;

            case 'activity':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                for ( $i = 1; $i <= $featured_package_count; $i++ ) {
                    if ( ! empty( $options['featured_package_content_activity_' . $i] ) ){
                        $page_post['id']      = $options['featured_package_content_activity_' . $i];

						$cat_image = get_term_meta( $page_post['id'], 'wp_travel_trip_type_image_id', true);
						$terms = get_term_by( 'id',  $page_post['id'], 'activity' );
							
						if ( ! empty( $terms ) && !is_wp_error($terms)) :
							$page_post['image'] = ! empty( $cat_image ) ? wp_get_attachment_url( $cat_image ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
							$page_post['title']   = $terms->name;
							$page_post['url']     = get_term_link( $page_post['id'], 'activity' );
							$page_post['count']   = $terms->count;
						endif;
                    }

                    if ( ! empty(  $options['featured_package_content_activity_' . $i] ) )
                        array_push( $content, $page_post );
                }  
                   
            break;

			default:
			break;
		}

		// wp_reset_postdata();
		if ( ! empty( $content ) ) {
				$input = $content;
		}
		return $input;
	}
endif;

// Destination section content details.
add_filter( 'moun10_pro_filter_featured_package_section_details', 'moun10_pro_get_featured_package_section_details' );


if ( ! function_exists( 'moun10_pro_render_featured_package_section' ) ) :
	/**
	 * Start Destination section
	 *
	 * @return string Destination content
	 * @since Moun10 Pro 1.0.0
	 *
	 */
	 function moun10_pro_render_featured_package_section( $content_details = array() ) {
		$options = moun10_pro_get_theme_options();

		$featured_package_content_type  	= $options['featured_package_content_type'];
		$featured_package_btn_label 		= $options['featured_package_btn_label'];

		if ( empty( $content_details ) ) {
				return;
        } ?>
    
        <div id="featured-package" class="relative page-section">
            <div class="wrapper">
            	<?php if ( is_customize_preview()): ?>
                      <?php moun10_pro_section_tooltip( 'featured-package' ); ?>
                  <?php endif ?>
                <div class="section-header">
                    <p class="section-subtitle"><?php echo esc_html($options['featured_package_sub_title']); ?></p>
                    <h2 class="section-title"><?php echo esc_html($options['featured_package_title']); ?></h2>
                </div><!-- .section-header -->   

                <div class="section-content col-<?php echo esc_attr( $options['featured_package_column_type'] ); ?> clear">
                    <?php foreach ($content_details as $content): ?>
                        <article>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'])?>');">
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                <?php if (  $options['featured_package_content_type'] !== 'category' ): ?>
                                	<span><?php  echo sprintf('<p>%d&nbsp;%s</p>',esc_html($content['count']), __('Packages','moun10-pro')); ?></span>
                                	<?php else: ?>
                                		<span><?php  echo sprintf('<p>%d&nbsp;%s</p>',esc_html($content['count']), __('Posts','moun10-pro')); ?></span>
                                <?php endif ?>

                            </header>   
                        </div><!-- .featured-image -->
                    </article>
                    <?php endforeach; ?>

                </div><!-- .section-content -->

                <?php if ( !empty( $featured_package_btn_label ) ): ?>
                	<div class="read-more">
	                    <a href="<?php echo esc_url($options['featured_package_btn_url']); ?>" class="btn"><?php echo esc_html($featured_package_btn_label); ?></a>
	                </div><!-- .read-more -->
                <?php endif ?>
                
            </div><!-- .wrapper -->
        </div>
<?php }
endif;