<?php
/**
 * Testimonial section
 *
 * This is the template for the content of Testimonial section
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */

if ( ! function_exists( 'moun10_pro_add_testimonial_section' ) ) :
    /**
    * Add testimonial section
    *
    *@since Moun10 Pro 1.0.0
    */
    function moun10_pro_add_testimonial_section() {
    	$options = moun10_pro_get_theme_options();
        // Check if testimonial is enabled on frontpage
        $testimonial_enable = apply_filters( 'moun10_pro_section_status', true, 'testimonial_section_enable' );

         if ( !in_array( $options['home_layout'], array( 'default-design', 'second-design', 'third-design', 'fourth-design', 'fifth-design', 'sixth-design', 'seventh-design' ) ) ) {
             $testimonial_enable = false;
        }

        if ( true !== $testimonial_enable ) {
            return false;
        }
        // Get testimonial section details
        $section_details = array();
        $section_details = apply_filters( 'moun10_pro_filter_testimonial_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return ;
        }

        // Render testimonial section now.
        moun10_pro_render_testimonial_section( $section_details );
    }
endif;

if ( ! function_exists( 'moun10_pro_get_testimonial_section_details' ) ) :
    /**
    * testimonial section details.
    *
    * @since Moun10 Pro 1.0.0
    * @param array $input testimonial section details.
    */
    function moun10_pro_get_testimonial_section_details( $input ) {
        $options = moun10_pro_get_theme_options();

        // Content type.
        $testimonial_content_type   = $options['testimonial_content_type'];
        $testimonial_count          = isset($options['testimonial_posts_count'] ) ? $options['testimonial_posts_count'] : 2;

        $content = array();
        switch ( $testimonial_content_type ) {
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_page_' . $i] ) )
                        $page_ids[] = $options['testimonial_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    );
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_post_' . $i] ) )
                        $post_ids[] = $options['testimonial_content_post_' . $i];
                }

                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $testimonial_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );
            break;

            case 'category':
                $cat_id = ! empty( $options['testimonial_category'] ) ? $options['testimonial_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $testimonial_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );
            break;

            default:
            break;
        }
        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) :
            $i = 1;
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['content']   = moun10_pro_trim_content(25);
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                $page_post['sub_title'] = isset($options['testimonial_post_sub_title_'.$i])?$options['testimonial_post_sub_title_'.$i] : '';
                // Push to the main array.
                array_push( $content, $page_post );
                $i++;
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// testimonial section content details.
add_filter( 'moun10_pro_filter_testimonial_section_details', 'moun10_pro_get_testimonial_section_details' );


if ( ! function_exists( 'moun10_pro_render_testimonial_section' ) ) :
  /**
   * Start testimonial section
   *
   * @return string testimonial content
   * @since Moun10 Pro 1.0.0
   *
   */
   function moun10_pro_render_testimonial_section( $content_details = array() ) {
    $options            = moun10_pro_get_theme_options();
    $section_sub_title  = $options['testimonial_section_sub_title'];
    if ( empty( $content_details ) ) {
        return;
    } ?>

       <div id="testimonial" class="page-section">
           <div class="wrapper">
                <?php if ( is_customize_preview()): ?>
                  <?php moun10_pro_section_tooltip( 'testimonial' ); ?>
                <?php endif ?>
               <div class="section-header">
                   <p class="section-subtitle"><?php echo esc_html($section_sub_title); ?></p>
                   <h2 class="section-title"><?php echo esc_html($options['testimonial_section_title']); ?></h2>
               </div><!-- .section-header -->

               <div class="testimonial-slider" data-slick='{"slidesToShow": 3, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": true, "arrows":false, "centerMode": true, "autoplay": true, "draggable": true, "fade": false }'>
                <?php foreach ($content_details as $i=>$content): ?>
                   <article>
                       <div class="featured-image">
                           <img src="<?php echo esc_url($content['image']); ?>" alt="client-01">
                           <header class="entry-header">
                               <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                               <p class="position"><?php echo esc_html($content['sub_title']); ?></p>
                           </header>
                       </div><!-- .featured-image -->

                       <div class="entry-content">
                           <p><?php echo wp_kses_post($content['content']);?></p>
                       </div><!-- .entry-content -->
                   </article>
                <?php endforeach;?>
               </div><!-- .testimonial-slider -->
           </div><!-- .wrapper -->
       </div><!-- #testimonials -->
    <?php
    }
endif; ?>
